@@ -24,9 +24,6 @@ sub new {
 sub add_response {
     my $self = shift;
     my $response = shift;
-    my $geocoder = shift;
-
-    $self->{geocoder} = $geocoder;
 
     if( $response->{longitude} && $response->{latitude} ) {
         push @{$self->{responses}}, $response;
@@ -34,13 +31,21 @@ sub add_response {
     }
     else { return( 0 ) };
 
+    $self->_sort_responses();
+
     return( 1 );
 };
 
 
+sub set_geocoder { $_[0]->{geocoder} = $_[1]; };
+sub set_status { $_[0]->{status} = $_[1]; };
+
+
 sub get_location { return( $_[0]->{location} ) };
 sub get_response_code { return( $_[0]->{response_code} ) };
 sub get_geocoder { return( $_[0]->{geocoder} ) };
+sub get_status { return( $_[0]->{status} ) };
+
 
 sub get_responses {
     my $self = shift;
@@ -49,4 +54,20 @@ sub get_responses {
 };
 
 
+sub _sort_responses {
+    my $self = shift;
+
+    my $tmp_responses = [];
+
+    foreach my $response ( sort { $b->{accuracy} <=> $a->{accuracy} } @{$self->{responses}} ) {
+        push @{$tmp_responses}, $response;
+    };
+
+    $self->{responses} = $tmp_responses;
+
+    return;
+};
+
+
+
 1;
\ No newline at end of file
